# Here we create a super simple pod that we can reach via IP
# Using nginx as the service to expose

locals {
    sanity = {
        namespace = "sanity"
        service   = "web-health"
        port      = 30808
    }
}

resource kubernetes_namespace sanity {
    metadata {
        name = local.sanity.namespace
    }
}

resource kubernetes_pod nginx {
    metadata {
        name = local.sanity.service
        labels = {
            app = local.sanity.service
        }
    }
    spec {
        container {
            image = "nginx:latest"
            name  = "nginx"
            resources {
                limits = {
                    cpu    = "200m"
                    memory = "64Mi"
                }
            }
            liveness_probe {
                http_get {
                    path = "/"
                    port = 80
                }

                initial_delay_seconds = 30
                period_seconds = 30
            }
        }
    }
}

resource kubernetes_service nginx {
    metadata {
        name = local.sanity.service
    }
    spec {
        selector = {
            app = local.sanity.service
        }
        port {
            port        = 8080
            target_port = 80
            node_port   = local.sanity.port
        }
        type      = "NodePort"
    }
}

